@@ -22,23 +22,38 @@
 
 K_PLUGIN_CLASS_WITH_JSON(CDDBModule, "kcm_cddb.json")
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 CDDBModule::CDDBModule(QWidget *parent, const QVariantList &args)
   : KCModule(parent, args)
+#else
+CDDBModule::CDDBModule(QObject *parent, const KPluginMetaData &metaData)
+  : KCModule(parent, metaData)
+#endif
 {
   setButtons(Default | Apply | Help);
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
   widget_ = new CDDBConfigWidget(this);
+#else
+  widget_ = new CDDBConfigWidget(widget());
+#endif
 
   KCDDB::Config* cfg = new KCDDB::Config();
   cfg->load();
 
   addConfig(cfg, widget_);
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
   QVBoxLayout * layout = new QVBoxLayout(this);
+#else
+  QVBoxLayout * layout = new QVBoxLayout(widget());
+#endif
 
   layout->addWidget(widget_);
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
   setQuickHelp(i18n("CDDB is used to get information like artist, title and song-names in CD's"));
+#endif
 
   load();
 }
@@ -49,7 +64,6 @@ CDDBModule::defaults()
   KCModule::defaults();
 
   KCDDB::Config config;
-  updateWidgetsFromConfig( config );
 }
 
   void
@@ -58,31 +72,6 @@ CDDBModule::checkSettings() const
   KCDDB::Config config;
 
   config.load();
-
-  if (config.smtpHostname().isEmpty() || config.emailAddress().isEmpty()
-      || !config.emailAddress().contains(QLatin1String( "@" )) ||
-      (!config.replyTo().isEmpty() && !config.replyTo().contains(QLatin1String( "@" ))))
-
-  {
-    if (config.freedbSubmitTransport() == KCDDB::Submit::SMTP)
-    {
-      KMessageBox::error(widget_, i18n("freedb has been set to use HTTP for submissions "
-                                    "because the email details you have entered are "
-                                    "incomplete. Please review your email settings "
-                                    "and try again."), i18n("Incorrect Email Settings"));
-      config.setFreedbSubmitTransport(KCDDB::Submit::HTTP);
-
-      config.save();
-    }
-  }
-}
-
-  void
-CDDBModule::updateWidgetsFromConfig(const KCDDB::Config & config)
-{
-  bool smtpUserIsEmpty = config.smtpUsername().isEmpty();
-  widget_->needsAuthenticationBox->setChecked(!smtpUserIsEmpty);
-  widget_->kcfg_smtpUsername->setEnabled(!smtpUserIsEmpty);
 }
 
   void
@@ -100,9 +89,9 @@ CDDBModule::load()
 
   KCDDB::Config config;
   config.load();
-  updateWidgetsFromConfig(config);
 }
 
-// vim:tabstop=2:shiftwidth=2:expandtab:cinoptions=(s,U1,m1
-
 #include "kcmcddb.moc"
+#include "moc_kcmcddb.cpp"
+
+// vim:tabstop=2:shiftwidth=2:expandtab:cinoptions=(s,U1,m1
