@@ -23,6 +23,7 @@
 
 #include <QCryptographicHash>
 #include <QDebug>
+#include <QRegExp>
 
 #include <cstdio>
 #include <cstring>
@@ -297,7 +298,9 @@ namespace KCDDB
         if ( f.exists() && f.open(QIODevice::ReadOnly) )
         {
           QTextStream ts(&f);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
           ts.setCodec("UTF-8");
+#endif
           QString cddbData = ts.readAll();
           f.close();
           CDInfo info;
@@ -345,4 +348,6 @@ namespace KCDDB
   }
 }
 
+#include "moc_musicbrainzlookup.cpp"
+
 // vim:tabstop=2:shiftwidth=2:expandtab:cinoptions=(s,U1,m1
